@@ -1,5 +1,5 @@
 -- DAV.hs: WebDAV client library
--- Copyright © 2012-2013  Clint Adams
+-- Copyright © 2012-2014  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -53,11 +53,12 @@ module Network.Protocol.HTTP.DAV (
 import Network.Protocol.HTTP.DAV.TH
 
 import Control.Applicative (liftA2, Applicative)
+import Control.Error (EitherT(..))
 import Control.Exception.Lifted (catchJust, finally, bracketOnError)
 import Control.Lens ((^.), (.=), (%=))
 import Control.Monad (liftM, liftM2, when, MonadPlus)
 import Control.Monad.Base (MonadBase(..))
-import Control.Monad.Error (ErrorT, MonadError, runErrorT)
+import Control.Monad.Error (MonadError)
 import Control.Monad.Fix (MonadFix)
 import Control.Monad.Trans (lift, MonadTrans)
 import Control.Monad.IO.Class (liftIO, MonadIO)
@@ -81,11 +82,11 @@ import Text.Hamlet.XML (xml)
 
 import Data.CaseInsensitive (mk)
 
-newtype DAVT m a = DAVT { runDAVT :: ErrorT String (StateT DAVContext m) a }
+newtype DAVT m a = DAVT { runDAVT :: EitherT String (StateT DAVContext m) a }
     deriving (Applicative, Functor, Monad, MonadBase b, MonadError String, MonadFix, MonadIO, MonadPlus, MonadState DAVContext)
 
 instance MonadBaseControl b m => MonadBaseControl b (DAVT m) where
-   newtype StM (DAVT m) a = StDAVT { unStDAVT :: StM (ErrorT String (StateT DAVContext m)) a }
+   newtype StM (DAVT m) a = StDAVT { unStDAVT :: StM (EitherT String (StateT DAVContext m)) a }
    liftBaseWith f = DAVT . liftBaseWith $ \r -> f $ liftM StDAVT . r . runDAVT
    restoreM       = DAVT . restoreM . unStDAVT
 
@@ -96,7 +97,7 @@ evalDAVT :: MonadIO m => String -> DAVT m a -> m (Either String a)
 evalDAVT u f = do
     mgr <- liftIO $ newManager tlsManagerSettings
     req <- liftIO $ parseUrl u
-    r <- (evalStateT . runErrorT . runDAVT) f $ DAVContext [] req B.empty B.empty [] Nothing mgr Nothing "hDav-using application"
+    r <- (evalStateT . runEitherT . runDAVT) f $ DAVContext [] req B.empty B.empty [] Nothing mgr Nothing "hDav-using application"
     liftIO $ closeManager mgr
     return r
 
@@ -127,10 +128,10 @@ davRequest meth addlhdrs rbody = do
                , fmap ((,) (mk "Depth") . BC8.pack . show) (ctx ^. depth)
                ] ++ addlhdrs
         req = (ctx ^. baseRequest) { method = meth, requestHeaders = hdrs, requestBody = rbody }
-        authreq = applyBasicAuth (ctx ^. basicusername) (ctx ^. basicpassword) req
-    liftIO (catchJust (matchStatusCodeException unauthorized401)
-                      (httpLbs req (ctx ^. httpManager))
-                      (\_ -> httpLbs authreq (ctx ^. httpManager)))
+        authreq = if B.null (ctx ^. basicusername) && B.null (ctx ^. basicpassword)
+            then req
+            else applyBasicAuth (ctx ^. basicusername) (ctx ^. basicpassword) req
+    liftIO (httpLbs authreq (ctx ^. httpManager))
 
 matchStatusCodeException :: Status -> HttpException -> Maybe ()
 matchStatusCodeException want (StatusCodeException s _ _)
