@@ -1,5 +1,5 @@
 -- hdav.hs: WebDAV client
--- Copyright © 2012-2013  Clint Adams
+-- Copyright © 2012-2014  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -34,8 +34,8 @@ import Network.URI (normalizePathSegments)
 
 import Network.Protocol.HTTP.DAV (DAVT, evalDAVT, setCreds, setDepth, setUserAgent, getPropsM, getContentM, putContentM, putPropsM, delContentM, moveContentM, mkCol, Depth(..), caldavReportM, withLockIfPossible, withLockIfPossibleForDelete)
 
-import Options.Applicative.Builder (argument, command, help, idm, info, long, metavar, option, progDesc, str, strOption, subparser)
-import Options.Applicative.Extra (execParser)
+import Options.Applicative.Builder (argument, command, help, idm, info, long, metavar, option, prefs, progDesc, showHelpOnError, str, strOption, subparser)
+import Options.Applicative.Extra (customExecParser)
 import Options.Applicative.Types (Parser)
 
 data Options = Options {
@@ -163,12 +163,12 @@ dispatch (CaldavReport o) = doReport o
 
 main :: IO ()
 main = withSocketsDo $ do
-    putStrLn $ "hDAV version " ++ showVersion version ++ ", Copyright (C) 2012-2013  Clint Adams\n\
+    putStrLn $ "hDAV version " ++ showVersion version ++ ", Copyright (C) 2012-2014  Clint Adams\n\
    \hDAV comes with ABSOLUTELY NO WARRANTY.\n\
    \This is free software, and you are welcome to redistribute it\n\
    \under certain conditions.\n"
 
-    execParser (info cmd idm) >>= dispatch
+    customExecParser (prefs showHelpOnError) (info cmd idm) >>= dispatch
 
 cmd :: Parser Command
 cmd = subparser
